﻿using NavigationDrawer.Themes;
using NavigationDrawer.ViewModel;
using Syncfusion.XForms.Border;
using Syncfusion.XForms.TabView;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Xamarin.Forms;

namespace NavigationDrawer
{
    public partial class MainPage : ContentPage
    {
        public MainPage()
        {
            InitializeComponent();
            ProcessSfTab(SLATabs, SLATabs.SelectedIndex);

            TrendLineModel model = new TrendLineModel();
            chartTrendline.HeightRequest = 400;
            TrendLineAchieved.ItemsSource = model.AchievedData;
            TrendLineAchieved.XBindingPath = "Name";
            TrendLineAchieved.YBindingPath = "ChartValue";

            TrendLineBreached.ItemsSource = model.BreachedData;
            TrendLineBreached.XBindingPath = "Name";
            TrendLineBreached.YBindingPath = "ChartValue";
        }
        #region page events
        private void NumericalAxis_LabelCreated(object sender, Syncfusion.SfChart.XForms.ChartAxisLabelEventArgs e)
        {
            double dblLabelContent = Convert.ToDouble(e.LabelContent);
            string formattedLabelContent = "";
            if (dblLabelContent > 999999)
            {
                double shortenLabelContent = dblLabelContent / 1000000;
                formattedLabelContent = Math.Floor(shortenLabelContent * 100) / 100 + "M";
            }
            else if (dblLabelContent > 999)
            {
                double shortenLabelContent = dblLabelContent / 1000;
                formattedLabelContent = Math.Floor(shortenLabelContent * 100) / 100 + "K";
            }
            else
            {
                formattedLabelContent = dblLabelContent + "";
            }

            e.LabelContent = formattedLabelContent;
        }
       
        private void SLATabs_SelectionChanged(object sender, Syncfusion.XForms.TabView.SelectionChangedEventArgs e)
        {
            var tabView = sender as SfTabView;
            ProcessSfTab(tabView, e.Index);

        }


        private void NumericalAxis_ActualRangeChanged(object sender, Syncfusion.SfChart.XForms.ActualRangeChangedEventArgs e)
        {
            var delta = (double)e.ActualMaximum - (double)e.ActualMinimum;
            e.ActualMaximum = e.VisibleMaximum = (double)e.ActualMaximum + (0.15 * delta); // increase 15% of axis height compare to default. 
        }

        private void Switch_StateChanged(object sender, Syncfusion.XForms.Buttons.SwitchStateChangedEventArgs e)
        {
           
        }
        
        private void BtnHome_Clicked(object sender, EventArgs e)
        {

        }

        private void BtnTheme_Clicked(object sender, EventArgs e)
        {
            if (!App.isDarkTheme)
            {
                ICollection<ResourceDictionary> mergedDictionaries = Application.Current.Resources.MergedDictionaries;
                var lightTheme = mergedDictionaries.OfType<LightTheme>().FirstOrDefault();
                if (lightTheme != null)
                {
                    mergedDictionaries.Remove(lightTheme);
                }

                mergedDictionaries.Add(new DarkTheme());

                App.isDarkTheme = true;
            }
            else
            {
                ICollection<ResourceDictionary> mergedDictionaries = Application.Current.Resources.MergedDictionaries;
                var darkTheme = mergedDictionaries.OfType<DarkTheme>().FirstOrDefault();
                if (darkTheme != null)
                {
                    mergedDictionaries.Remove(darkTheme);
                }

                mergedDictionaries.Add(new LightTheme());

                App.isDarkTheme = false;
            }
        }

        private void FilterButton_Clicked(object sender, EventArgs e)
        {
            navigationDrawer.ToggleDrawer();
        }

        private void BtnFilter_Clicked(object sender, EventArgs e)
        {

        }
        #endregion
        private void ProcessSfTab(SfTabView tabView, int selectedIndex)
        {
            SetSelectionIndicator(tabView, selectedIndex);
            //GetSelectedContent(selectedIndex);
        }


        private void SetSelectionIndicator(SfTabView tabView, int selectedIndex)
        {
            for (int i = 0; i < tabView.Items.Count; i++)
            {
                var tabItem = tabView.Items[i] as SfTabItem;
                var borderStack = tabItem.HeaderContent as StackLayout;
                var border = (borderStack.Children[1] as SfBorder);
                var initialBorder = (borderStack.Children[0] as SfBorder);
                if (i == selectedIndex)
                {
                    border.IsVisible = true;
                    initialBorder.IsVisible = false;
                }
                else
                {
                    border.IsVisible = false;
                    initialBorder.IsVisible = true;
                }
            }
        }
    }
}
